"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.tabBarIncrement = tabBarIncrement;
exports.tabBarDecrementAndRedirect = tabBarDecrementAndRedirect;
exports.tabBarDecrement = tabBarDecrement;
exports.redirect = redirect;
exports.linkTo = linkTo;
exports.goBack = goBack;
exports.goForward = goForward;
exports.go = go;
exports.parentRouteCompVisible = parentRouteCompVisible;
exports.rollBack = rollBack;

var _reactRouterRedux = require("react-router-redux");

var _kitTypes = require("../constants/kitTypes");

function tabBarIncrement(currentLocation) {
  return {
    type: _kitTypes.TABBAR_INCREMENT,
    currentLocation: currentLocation
  };
}

function tabBarDecrementAndRedirect(currentLocation) {
  return function (dispatch, getState) {
    var _getState = getState(),
        tabBarLocations = _getState.tabBarLocations,
        routing = _getState.routing;

    var currentPathname = currentLocation.pathname;
    var routingPathname = routing.locationBeforeTransitions.pathname;

    if (tabBarLocations.length > 1) {
      for (var i = 0, len = tabBarLocations.length; i < len; i++) {
        var locationPathname = tabBarLocations[i].pathname;

        if (locationPathname === currentPathname) {
          if (i < tabBarLocations.length - 1) {
            if (routingPathname === currentPathname) {
              dispatch(redirect(tabBarLocations[i + 1]));
            }
          } else if (routingPathname === currentPathname) {
            dispatch(redirect(tabBarLocations[i - 1]));
          }
        }
      }
    }

    dispatch(tabBarDecrement(currentLocation));
  };
}

function tabBarDecrement(currentLocation) {
  return {
    type: _kitTypes.TABBAR_DECREMENT,
    currentLocation: currentLocation
  };
}

function redirect(location) {
  return function (dispatch) {
    dispatch((0, _reactRouterRedux.replace)(location));
  };
}

function linkTo(location) {
  return function (dispatch) {
    dispatch((0, _reactRouterRedux.push)(location));
  };
}

function goBack() {
  return function (dispatch) {
    dispatch((0, _reactRouterRedux.goBack)());
  };
}

function goForward() {
  return function (dispatch) {
    dispatch((0, _reactRouterRedux.goForward)());
  };
}

function go(number) {
  return function (dispatch) {
    dispatch((0, _reactRouterRedux.go)(number));
  };
}

function parentRouteCompVisible(statue) {
  return {
    type: _kitTypes.PARENT_ROUTE_COMP_VIS,
    visible: statue
  };
}

function rollBack(namespace) {
  return {
    type: _kitTypes.STATE_ROLL_BACK,
    namespace: namespace
  };
}